.. role:: raw-html(raw)
   :format: html

.. raw:: html

   <style>
      .toctree-wrapper {
         display: none !important;
      }
      h5 {
         margin-top: 0 !important;
      }
   </style>


Tutorials
=========

.. grid:: 1 1 2 2
   :class-container: tutorial-card-section
   :gutter: 3

   .. grid-item-card:: 
      :link: notebooks/tutorials/walkthrough.ipynb
      :class-card: code-surface
      :class-body: code-surface

      .. raw:: html

         <div class="d-flex align-items-center">
            <img src="../_static/images/tutorials/walkthrough.webp" class="img-fluid" style="max-width: 50px; margin-right: 20px;">
            <div>
               <h5 class="code-surface card-title">Walkthrough</h5>
               <p class="code-surface card-text">Learn the basics</p>
            </div>
         </div>

   .. grid-item-card:: 
      :link: notebooks/tutorials/ioi_patching.ipynb
      :class-card: code-surface
      :class-body: code-surface

      .. raw:: html

         <div class="d-flex align-items-center">
            <img src="../_static/images/tutorials/activation_patching.webp" class="img-fluid" style="max-width: 50px; margin-right: 20px;">
            <div>
               <h5 class="code-surface card-title">Activation Patching</h5>
               <p class="code-surface card-text">Causal intervention</p>
            </div>
         </div>

   .. grid-item-card:: 
      :link: notebooks/tutorials/attribution_patching.ipynb
      :class-card: code-surface
      :class-body: code-surface

      .. raw:: html

         <div class="d-flex align-items-center">
            <img src="../_static/images/tutorials/attribution_patching.webp" class="img-fluid" style="max-width: 50px; margin-right: 20px;">
            <div>
               <h5 class="code-surface card-title">Attribution Patching</h5>
               <p class="code-surface card-text">Approximate patching</p>
            </div>
         </div>

   .. grid-item-card:: 
      :link: notebooks/tutorials/logit_lens.ipynb
      :class-card: code-surface
      :class-body: code-surface

      .. raw:: html

         <div class="d-flex align-items-center">
            <img src="../_static/images/tutorials/logit_lens.webp" class="img-fluid" style="max-width: 50px; margin-right: 20px;">
            <div>
               <h5 class="code-surface card-title">Logit Lens</h5>
               <p class="code-surface card-text">Decode activations</p>
            </div>
         </div>

   .. grid-item-card:: 
      :link: notebooks/tutorials/future_lens.ipynb
      :class-card: code-surface
      :class-body: code-surface

      .. raw:: html

         <div class="d-flex align-items-center">
            <img src="../_static/images/tutorials/future_lens.webp" class="img-fluid" style="max-width: 50px; margin-right: 20px;">
            <div>
               <h5 class="code-surface card-title">Future Lens</h5>
               <p class="code-surface card-text">Probe future tokens</p>
            </div>
         </div>

   .. grid-item-card:: 
      :link: notebooks/tutorials/function_vectors.ipynb
      :class-card: code-surface
      :class-body: code-surface

      .. raw:: html

         <div class="d-flex align-items-center">
            <img src="../_static/images/tutorials/function_vectors.webp" class="img-fluid" style="max-width: 50px; margin-right: 20px;">
            <div>
               <h5 class="code-surface card-title">Function Vectors</h5>
               <p class="code-surface card-text">Lambdas</p>
            </div>
         </div>

   .. grid-item-card:: 
      :link: notebooks/tutorials/sae.ipynb
      :class-card: code-surface
      :class-body: code-surface

      .. raw:: html

         <div class="d-flex align-items-center">
            <img src="../_static/images/tutorials/dictionary_learning.webp" class="img-fluid" style="max-width: 50px; margin-right: 20px;">
            <div>
               <h5 class="code-surface card-title">Dictionary Learning</h5>
               <p class="code-surface card-text">Sparse autoencoders</p>
            </div>
         </div>



.. toctree::
   :maxdepth: 1

   notebooks/tutorials/walkthrough.ipynb
   notebooks/tutorials/ioi_patching.ipynb
   notebooks/tutorials/attribution_patching.ipynb
   notebooks/tutorials/logit_lens.ipynb
   notebooks/tutorials/future_lens.ipynb
   notebooks/tutorials/function_vectors.ipynb
   notebooks/tutorials/sae.ipynb


